// Copyright (c) Microsoft Corporation. All rights reserved.

#pragma once

#include <string>
#include <string_view>
#include <vector>

#include <boost/filesystem.hpp>

namespace Azure { namespace Device { namespace ErrorReporting {
namespace Submitter {

class Report
{
  public:
    Report() = delete;

    Report(std::string_view eventType);

    const std::string& GetEventType() { return m_eventType; }
    const std::vector<std::string>& GetBucketingParameters()
    {
        return m_bucketingParameters;
    }
    const std::vector<std::pair<boost::filesystem::path, boost::filesystem::path>>&
    GetRegisteredPaths()
    {
        return m_registeredPaths;
    }
    uint64_t GetId() { return m_reportId; }

    void AddBucketingParameter(std::string_view parameter);

    void RegisterPath(const boost::filesystem::path& sourcePath);

    void RegisterPathInSubdirectory(
        const boost::filesystem::path& sourcePath,
        const boost::filesystem::path& reportSubdirPath);

    void WriteMetadata(boost::filesystem::path& metadataPath);

  private:
    std::string m_eventType;
    std::vector<std::string> m_bucketingParameters;
    std::vector<std::pair<boost::filesystem::path, boost::filesystem::path>>
        m_registeredPaths;
    uint64_t m_reportId = 0;
};

}}}}
