// Copyright (c) Microsoft Corporation. All rights reserved.

#pragma once

#include <memory>
#include <string_view>

#include <azure-device-errorreporting-submitter/Report.h>
#include <boost/filesystem.hpp>

namespace Azure { namespace Device { namespace ErrorReporting {
namespace Submitter {

static const uintmax_t k_defaultMaxQueueSizeBytes = 1000 * 1024 * 1024;

struct QueueConfig
{
    uintmax_t MaxQueueSizeBytes = k_defaultMaxQueueSizeBytes;
};

class ReportQueue
{
  public:
    ReportQueue(const boost::filesystem::path& path);

    boost::filesystem::path GetSubmittedReportsPath()
    {
        return m_path / "submitted";
    }
    boost::filesystem::path GetPendingReportsPath()
    {
        return m_path / "pending";
    }
    const QueueConfig& GetQueueConfig() { return m_queueConfig; }
    bool IsFull() { return GetQueueSize() >= m_queueConfig.MaxQueueSizeBytes; }
    uintmax_t GetQueueSize();

    static std::unique_ptr<ReportQueue>
    OpenReportQueue(const boost::filesystem::path& path);

    static std::unique_ptr<ReportQueue> CreateReportQueue(
        const boost::filesystem::path& path,
        boost::filesystem::perms queuePermissions,
        boost::filesystem::perms pendingReportsPermissions,
        boost::filesystem::perms submittedReportsPermissions);

    std::unique_ptr<Report> CreateReport(std::string_view eventType);

    bool IsThrottled(Report& report);
    void Submit(Report& report);

  private:
    void ReadQueueConfig();

  private:
    boost::filesystem::path m_path;
    QueueConfig m_queueConfig;
};
}}}}
