// Copyright (c) Microsoft Corporation. All rights reserved.

#include "ErrorReportUploadServiceFactory.h"

#ifdef AZURE_DEVICE_ERRORREPORTING_UPLOADER_USE_HTTP_UPLOADER
    #include "HttpErrorReportUploadService.h"
    #include "LocalPolicyManager.h"
#endif

#ifdef AZURE_DEVICE_ERRORREPORTING_UPLOADER_USE_HVSOCKET_UPLOADER
    #include "HvSocketErrorReportUploadService.h"
    #include "RemotePolicyManager.h"
#endif

using namespace Azure::Device::Policy;

namespace Azure { namespace Device { namespace ErrorReporting {
namespace Uploader {

#ifdef AZURE_DEVICE_ERRORREPORTING_UPLOADER_USE_HTTP_UPLOADER
std::unique_ptr<ErrorReportUploadServiceBase>
ErrorReportUploadServiceFactory::CreateHttpErrorReportUploadService(
    LocalPolicyManager& localPolicyManager)
{
    return std::make_unique<HttpErrorReportUploadService>(localPolicyManager);
}
#endif

#ifdef AZURE_DEVICE_ERRORREPORTING_UPLOADER_USE_HVSOCKET_UPLOADER
std::unique_ptr<ErrorReportUploadServiceBase>
ErrorReportUploadServiceFactory::CreateHvSocketErrorReportUploadService(
    RemotePolicyManager& remotePolicyManager)
{
    return std::make_unique<HvSocketErrorReportUploadService>(remotePolicyManager);
}
#endif

}}}}