// Copyright (c) Microsoft Corporation. All rights reserved.

#pragma once

#include <string>
#include <vector>

#include <azure-device-errorreporting-submitter/ReportQueue.h>
#include <azure-device-util/Permission.h>
#include <boost/filesystem.hpp>

#include "INotifyMonitor.h"
#include "IPolicyManager.h"
#include "UploadConfigManager.h"

namespace Azure { namespace Device { namespace ErrorReporting {
namespace Uploader {

class ErrorReportUploadServiceBase : public INotifyMonitorCallbackReceiver
{
  public:
    ErrorReportUploadServiceBase(Policy::IPolicyManager& policyManager);
    virtual ~ErrorReportUploadServiceBase() = default;

    void UpdateTelemetryPermission();

    void INotifyMonitorCallback(std::vector<INotifyMonitorEvent> events);

    void Run();
    void Stop();

    virtual void UploadReport(const boost::filesystem::path& reportPath) = 0;
    void ProcessReportQueue(const boost::filesystem::path& queuePath);

  private:
    std::unique_ptr<Submitter::ReportQueue> m_reportQueue;
    INotifyMonitor m_reportQueueWatcher;

  protected:
    Policy::IPolicyManager& m_policyManager;
    UploadConfigManager m_uploadConfigManager;
};

}}}}
