// Copyright (c) Microsoft Corporation. All rights reserved.

#pragma once

#include <optional>
#include <string>
#include <vector>

#include <boost/filesystem.hpp>

namespace Azure { namespace Device { namespace Utils {

class Process
{
  public:
    struct CommandResult
    {
        int32_t ExitCode = -1;
        std::vector<std::string> Output;
        std::vector<std::string> Error;
    };

    static CommandResult RunCommand(
        std::string_view executable,
        const std::vector<std::string>& args = {},
        std::optional<boost::filesystem::path> inputPath = std::nullopt);

    static void SpawnDetachedProcess(
        std::string_view executable,
        const std::vector<std::string>& args = {});

  private:
    static std::string GetPathForBinary(std::string_view binaryName);
};

}}}
